import java.util.Random;

/**
 * Represents a primitive stomach. The stomach can eat (intake) food.
 * The stomach can also digest a random amount of the food eaten.
 */
public class Stomach{

    // Instance variables
    private Random rng;
    private double amountEaten;
    private double amountDigested;
    
    /**
     * Creates a primitive stomach
     */
    public Stomach(){
        rng = new Random();
        amountEaten = 0.0;
        amountDigested = 0.0;
    }
    
    /**
     * Causes the stomach to intake the specified amount of 
     * food. The specified amount is added to the total amount
     * of food currently in the stomach.
     * @param amount Amount of food to eat
     */
    public void ingest(double amount){
        amountEaten += amount;
    }
    
    /**
     * Causes a random amount of food in the stomach to be digested.
     */
    public void digest(){
        double amountToDigest = amountEaten*rng.nextDouble();
        amountEaten -= amountToDigest;
        amountDigested += amountToDigest;
    }
    
    /**
     * Returns current amount of food in the stomach
     * @return current amount of food in stomach
     */
    public double getAmountFood(){
        return amountEaten;
    }
    
    /**
     * Returns the total amount of food digested
     * @return cummulative amount of food digested
     */
    public double getAmountDigested(){
        return amountDigested;
    }
    
    public String toString(){
        return "[eaten=" + amountEaten + ", digested=" + amountDigested + "]";
    }
    
    
    
}